@@ -39,6 +39,9 @@
 /*** DOCUMENTATION
 	<managerEvent language="en_US" name="ConfbridgeStart">
 		<managerEventInstance class="EVENT_FLAG_CALL">
+			<since>
+				<version>12.0.0</version>
+			</since>
 			<synopsis>Raised when a conference starts.</synopsis>
 			<syntax>
 				<parameter name="Conference">
@@ -54,6 +57,9 @@
 	</managerEvent>
 	<managerEvent language="en_US" name="ConfbridgeEnd">
 		<managerEventInstance class="EVENT_FLAG_CALL">
+			<since>
+				<version>12.0.0</version>
+			</since>
 			<synopsis>Raised when a conference ends.</synopsis>
 			<syntax>
 				<parameter name="Conference">
@@ -69,6 +75,9 @@
 	</managerEvent>
 	<managerEvent language="en_US" name="ConfbridgeJoin">
 		<managerEventInstance class="EVENT_FLAG_CALL">
+			<since>
+				<version>12.0.0</version>
+			</since>
 			<synopsis>Raised when a channel joins a Confbridge conference.</synopsis>
 			<syntax>
 				<parameter name="Conference">
@@ -99,6 +108,9 @@
 	</managerEvent>
 	<managerEvent language="en_US" name="ConfbridgeLeave">
 		<managerEventInstance class="EVENT_FLAG_CALL">
+			<since>
+				<version>12.0.0</version>
+			</since>
 			<synopsis>Raised when a channel leaves a Confbridge conference.</synopsis>
 			<syntax>
 				<parameter name="Conference">
@@ -122,6 +134,9 @@
 	</managerEvent>
 	<managerEvent language="en_US" name="ConfbridgeRecord">
 		<managerEventInstance class="EVENT_FLAG_CALL">
+			<since>
+				<version>12.0.0</version>
+			</since>
 			<synopsis>Raised when a conference starts recording.</synopsis>
 			<syntax>
 				<parameter name="Conference">
@@ -137,6 +152,9 @@
 	</managerEvent>
 	<managerEvent language="en_US" name="ConfbridgeStopRecord">
 		<managerEventInstance class="EVENT_FLAG_CALL">
+			<since>
+				<version>12.0.0</version>
+			</since>
 			<synopsis>Raised when a conference that was recording stops recording.</synopsis>
 			<syntax>
 				<parameter name="Conference">
@@ -152,6 +170,9 @@
 	</managerEvent>
 	<managerEvent language="en_US" name="ConfbridgeMute">
 		<managerEventInstance class="EVENT_FLAG_CALL">
+			<since>
+				<version>12.0.0</version>
+			</since>
 			<synopsis>Raised when a Confbridge participant mutes.</synopsis>
 			<syntax>
 				<parameter name="Conference">
@@ -175,6 +196,9 @@
 	</managerEvent>
 	<managerEvent language="en_US" name="ConfbridgeUnmute">
 		<managerEventInstance class="EVENT_FLAG_CALL">
+			<since>
+				<version>12.0.0</version>
+			</since>
 			<synopsis>Raised when a confbridge participant unmutes.</synopsis>
 			<syntax>
 				<parameter name="Conference">
@@ -198,6 +222,9 @@
 	</managerEvent>
 	<managerEvent language="en_US" name="ConfbridgeTalking">
 		<managerEventInstance class="EVENT_FLAG_CALL">
+			<since>
+				<version>12.0.0</version>
+			</since>
 			<synopsis>Raised when a confbridge participant begins or ends talking.</synopsis>
 			<syntax>
 				<parameter name="Conference">
@@ -326,16 +353,28 @@ static struct ast_json *bridge_to_json(struct ast_bridge_snapshot *bridge_snapsh
 	return json_bridge;
 }
 
-static struct ast_json *pack_bridge_and_channels(
-	struct ast_json *json_bridge, struct ast_json *json_channels,
-	struct stasis_message * msg)
+static struct ast_json *pack_bridge_and_channel(
+	struct ast_json *json_bridge, struct ast_json *json_channel,
+	struct stasis_message *msg)
 {
 	const struct timeval *tv = stasis_message_timestamp(msg);
 	const char *msg_name = confbridge_event_type_to_string(stasis_message_type(msg));
-	const char *fmt = ast_json_typeof(json_channels) == AST_JSON_ARRAY ?
-		"{s: s, s: o, s: o, s: o }" : "{s: s, s: o, s: o, s: [ o ] }";
 
-	return ast_json_pack(fmt,
+	return ast_json_pack("{s: s, s: o, s: o, s: [o*]}",
+		"type", msg_name,
+		"timestamp", ast_json_timeval(*tv, NULL),
+		"bridge", json_bridge,
+		"channels", json_channel);
+}
+
+static struct ast_json *pack_bridge_and_channels(
+	struct ast_json *json_bridge, struct ast_json *json_channels,
+	struct stasis_message *msg)
+{
+	const struct timeval *tv = stasis_message_timestamp(msg);
+	const char *msg_name = confbridge_event_type_to_string(stasis_message_type(msg));
+
+	return ast_json_pack("{s: s, s: o, s: o, s: o}",
 		"type", msg_name,
 		"timestamp", ast_json_timeval(*tv, NULL),
 		"bridge", json_bridge,
@@ -352,7 +391,7 @@ static struct ast_json *pack_snapshots(	struct ast_bridge_snapshot *bridge_snaps
 	json_bridge = bridge_to_json(bridge_snapshot);
 	json_channel = channel_to_json(channel_snapshot, conf_blob, labels_blob);
 
-	return pack_bridge_and_channels(json_bridge, json_channel, msg);
+	return pack_bridge_and_channel(json_bridge, json_channel, msg);
 }
 
 static void send_message(const char *msg_name, char *conf_name, struct ast_json *json_object,
